<img src="https://docs.matflow.io/stable/_static/images/logo-90dpi.png" width="250" alt="MatFlow logo"/>

**Design, run, and share computational materials science workflows**

Documentation: [https://matflow.io/docs](https://matflow.io/docs)

## Acknowledgements


MatFlow was developed using funding from the [LightForm](https://lightform.org.uk/) EPSRC programme grant ([EP/R001715/1](https://gow.epsrc.ukri.org/NGBOViewGrant.aspx?GrantRef=EP/R001715/1))


<img src="https://lightform-group.github.io/wiki/assets/images/site/lightform-logo.png" width="150"/>
